@@ -1,7 +1,7 @@
 /*
   Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Copyright (c) 2010 Leo Franchi <lfranchi@kde.org>
-  Copyright (c) 2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -132,7 +132,7 @@ void MessageFactoryNG::createReplyAsync()
 
     if (auto hdr = m_origMsg->headerByType("List-Post")) {
         const QString hdrListPost = hdr->asUnicodeString();
-        if (hdrListPost.contains(QStringLiteral("mailto:"), Qt::CaseInsensitive)) {
+        if (hdrListPost.contains(QLatin1String("mailto:"), Qt::CaseInsensitive)) {
             QRegExp rx(QStringLiteral("<mailto:([^@>]+)@([^>]+)>"), Qt::CaseInsensitive);
             if (rx.indexIn(hdrListPost, 0) != -1) {   // matched
                 KMime::Types::Mailbox mailbox;
@@ -344,7 +344,7 @@ void MessageFactoryNG::createReplyAsync()
     //In-Reply-To = original msg-id
     msg->inReplyTo()->from7BitString(m_origMsg->messageID()->as7BitString(false));
 
-    msg->subject()->fromUnicodeString(MessageHelper::replySubject(m_origMsg), "utf-8");
+    msg->subject()->fromUnicodeString(MessageCore::StringUtil::replySubject(m_origMsg.data()), "utf-8");
 
     // If the reply shouldn't be blank, apply the template to the message
     if (m_quote) {
@@ -421,7 +421,7 @@ void MessageFactoryNG::createForwardAsync()
         msg->assemble();
     }
 
-    msg->subject()->fromUnicodeString(MessageHelper::forwardSubject(m_origMsg), "utf-8");
+    msg->subject()->fromUnicodeString(MessageCore::StringUtil::forwardSubject(m_origMsg.data()), "utf-8");
     MessageFactoryForwardJob *job = new MessageFactoryForwardJob;
     connect(job, &MessageFactoryForwardJob::forwardDone, this, &MessageFactoryNG::slotCreateForwardDone);
     job->setIdentityManager(m_identityManager);
@@ -449,7 +449,7 @@ QPair< KMime::Message::Ptr, QList< KMime::Content * > > MessageFactoryNG::create
         KMime::Message::Ptr firstMsg = MessageComposer::Util::message(items.first());
         const uint originalIdentity = identityUoid(firstMsg);
         MessageHelper::initFromMessage(msg, firstMsg, m_identityManager, originalIdentity);
-        msg->subject()->fromUnicodeString(MessageHelper::forwardSubject(firstMsg), "utf-8");
+        msg->subject()->fromUnicodeString(MessageCore::StringUtil::forwardSubject(firstMsg.data()), "utf-8");
     }
 
     MessageHelper::setAutomaticFields(msg, true);
@@ -638,7 +638,7 @@ KMime::Message::Ptr MessageFactoryNG::createDeliveryReceipt()
     }
     receiptTo.remove(QChar::fromLatin1('\n'));
 
-    KMime::Message::Ptr receipt = KMime::Message::Ptr(new KMime::Message);
+    KMime::Message::Ptr receipt(new KMime::Message);
     const uint originalIdentity = identityUoid(m_origMsg);
     MessageHelper::initFromMessage(receipt, m_origMsg, m_identityManager, originalIdentity);
     receipt->to()->fromUnicodeString(receiptTo, QStringLiteral("utf-8").toLatin1());
@@ -938,7 +938,7 @@ bool MessageFactoryNG::MDNMDNUnknownOption(const KMime::Message::Ptr &msg)
     if (auto hrd = msg->headerByType("Disposition-Notification-Options")) {
         notificationOptions = hrd->asUnicodeString();
     }
-    if (notificationOptions.contains(QStringLiteral("required"), Qt::CaseSensitive)) {
+    if (notificationOptions.contains(QLatin1String("required"), Qt::CaseSensitive)) {
         // ### hacky; should parse...
         // There is a required option that we don't understand. We need to
         // ask the user what we should do:
@@ -954,7 +954,7 @@ uint MessageFactoryNG::identityUoid(const KMime::Message::Ptr &msg)
         idString = hdr->asUnicodeString().trimmed();
     }
     bool ok = false;
-    int id = idString.toUInt(&ok);
+    uint id = idString.toUInt(&ok);
 
     if (!ok || id == 0) {
         id = m_identityManager->identityForAddress(msg->to()->asUnicodeString() + QLatin1String(", ") + msg->cc()->asUnicodeString()).uoid();
@@ -976,8 +976,8 @@ QString MessageFactoryNG::replaceHeadersInString(const KMime::Message::Ptr &msg,
     Q_ASSERT(rxDate.isValid());
 
     const QString sDate = KMime::DateFormatter::formatDate(
-        KMime::DateFormatter::Localized, msg->date()->dateTime().toTime_t());
-    qCDebug(MESSAGECOMPOSER_LOG) << "creating mdn date:" << msg->date()->dateTime().toTime_t() << sDate;
+        KMime::DateFormatter::Localized, msg->date()->dateTime().toSecsSinceEpoch());
+    qCDebug(MESSAGECOMPOSER_LOG) << "creating mdn date:" << msg->date()->dateTime().toSecsSinceEpoch() << sDate;
 
     int idx = 0;
     if ((idx = rxDate.indexIn(result, idx)) != -1) {
